@@ -22,17 +22,16 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-fno-semantic-interposition -march=armv5te -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=armv5te -O3 -pipe '
-           '-fstack-protector-strong -fno-plt',
+           '-march=armv5te -O3 -pipe -fno-plt -fno-semantic-interposition '
+           '-march=armv5te -O3 -pipe -fno-plt -march=armv5te -O3 -pipe '
+           '-fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=armv5te -O3 -pipe -fstack-protector-strong '
-                     '-fno-plt -fno-semantic-interposition',
+ 'CONFIGURE_CFLAGS': '-march=armv5te -O3 -pipe -fno-plt '
+                     '-fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -46,15 +45,15 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'CFLAGS=-march=armv5te -O3 -pipe -fstack-protector-strong "
-                "-fno-plt -fno-semantic-interposition' "
+                "'CFLAGS=-march=armv5te -O3 -pipe -fno-plt "
+                "-fno-semantic-interposition' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro "
                 "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.8.5/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.8.5/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.8.6/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.8.6/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -633,33 +632,29 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv5te -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
-                             '-fno-semantic-interposition -march=armv5te -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
-                             '-march=armv5te -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-fno-plt -fno-semantic-interposition '
+                             '-march=armv5te -O3 -pipe -fno-plt -march=armv5te '
+                             '-O3 -pipe -fno-plt -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration  '
                              '-I./Include/internal -I. -I./Include '
                              '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-fno-semantic-interposition -march=armv5te -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv5te -O3 -pipe '
-              '-fstack-protector-strong -fno-plt',
+              '-march=armv5te -O3 -pipe -fno-plt -fno-semantic-interposition '
+              '-march=armv5te -O3 -pipe -fno-plt -march=armv5te -O3 -pipe '
+              '-fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
                      '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=armv5te -O3 -pipe -fstack-protector-strong '
-                   '-fno-plt -fno-semantic-interposition -march=armv5te -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt -march=armv5te -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wall -march=armv5te -O3 -pipe -fno-plt '
+                   '-fno-semantic-interposition -march=armv5te -O3 -pipe '
+                   '-fno-plt -march=armv5te -O3 -pipe -fno-plt -std=c99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
@@ -676,11 +671,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=armv5te -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt '
+                        '-O3 -Wall -march=armv5te -O3 -pipe -fno-plt '
                         '-fno-semantic-interposition -march=armv5te -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -march=armv5te -O3 '
-                        '-pipe -fstack-protector-strong -fno-plt -std=c99 '
+                        '-fno-plt -march=armv5te -O3 -pipe -fno-plt -std=c99 '
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration  '
@@ -694,7 +687,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.5',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.6',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -736,9 +729,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.5 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.6 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.5 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.6 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -760,8 +753,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.8.5',
- 'abs_srcdir': '/build/python/src/Python-3.8.5',
+ 'abs_builddir': '/build/python/src/Python-3.8.6',
+ 'abs_srcdir': '/build/python/src/Python-3.8.6',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
